PCB Environment: PCBoardMesh::IndexRange Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Fields
PCBoardMesh::IndexRange Struct Reference

## Data Fields
struct { |
uint16_t Line {0} |
uint16_t Fan {0} |
uint16_t Quad {0} |
} | Start
struct { |
uint16_t Line {0} |
uint16_t Fan {0} |
uint16_t Quad {0} |
} | End

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/PCBoardMesh.hpp